``dossier.label`` is a Python package that provides an API to store and
query labels (or "ground truth") in a database backend via kvlayer,
which currently include support for PostgreSQL, Accumulo and Redis.

Installation
~~~~~~~~~~~~

``dossier.label`` is on PyPI and can be installed with ``pip``:

.. code:: bash

    pip install dossier.label

Currently, ``dossier.label`` requires Python 2.7. It is not yet Python 3
compatible.

Documentation
~~~~~~~~~~~~~

API documentation with examples is available as part of the Dossier
Stack documentation:
`http://dossier-stack.readthedocs.org <http://dossier-stack.readthedocs.org#module-dossier.label>`__
